@@ -1,5 +1,3 @@
-#!/usr/bin/python
-#
 # Licensed to the Software Freedom Conservancy (SFC) under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -34,10 +32,3 @@ class By(object):
     TAG_NAME = "tag name"
     CLASS_NAME = "class name"
     CSS_SELECTOR = "css selector"
-
-    @classmethod
-    def is_valid(cls, by):
-        for attr in dir(cls):
-            if by == getattr(cls, attr):
-                return True
-        return False
