@@ -29,7 +29,6 @@ from .switch_to import SwitchTo
 from .mobile import Mobile
 from .file_detector import FileDetector, LocalFileDetector
 from selenium.common.exceptions import WebDriverException
-from selenium.common.exceptions import InvalidSelectorException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.html5.application_cache import ApplicationCache
 
@@ -167,14 +166,14 @@ class WebDriver(object):
          - javascript_enabled - Whether the new session should support JavaScript.
          - browser_profile - A selenium.webdriver.firefox.firefox_profile.FirefoxProfile object. Only used if Firefox is requested.
         """
-        capabilities = {}
+        capabilities = {'desiredCapabilities': {}}
         for k, v in desired_capabilities.items():
             if k not in ('desiredCapabilities', 'requiredCapabilities'):
-                capabilities.setdefault('desiredCapabilities', {})[k] = v
+                capabilities['desiredCapabilities'][k] = v
             else:
                 capabilities[k] = v
         if browser_profile:
-            capabilities['requiredCapabilities']['firefox_profile'] = browser_profile.encoded
+            capabilities['desiredCapabilities']['firefox_profile'] = browser_profile.encoded
         response = self.execute(Command.NEW_SESSION, capabilities)
         self.session_id = response['sessionId']
         self.capabilities = response['value']
@@ -730,8 +729,6 @@ class WebDriver(object):
 
         :rtype: WebElement
         """
-        if not By.is_valid(by) or not isinstance(value, str):
-            raise InvalidSelectorException("Invalid locator values passed in")
         if self.w3c:
             if by == By.ID:
                 by = By.CSS_SELECTOR
@@ -756,8 +753,6 @@ class WebDriver(object):
 
         :rtype: list of WebElement
         """
-        if not By.is_valid(by) or not isinstance(value, str):
-            raise InvalidSelectorException("Invalid locator values passed in")
         if self.w3c:
             if by == By.ID:
                 by = By.CSS_SELECTOR
